@@ -74,11 +74,11 @@ using namespace std;
 
 #ifdef HAS_V4L2
 #include <errno.h>
+#include <fcntl.h>
 #include <linux/videodev2.h>
 #include <sys/ioctl.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
+#include <sys/types.h>
 #include <unistd.h>
 #endif
 
@@ -116,10 +116,8 @@ void WebcamSource::capture()
 const QList<int> & WebcamSource::getWebcamList()
 {
   _webcamList.clear();
-
 #if defined(HAS_V4L2)
-  int i = 0;
-  for (i = 0; i <= 10; ++i) {
+  for (int i = 0; i <= 10; ++i) {
     QString filename = QString("/dev/video%1").arg(i);
     if (!QFileInfo(filename).isReadable()) {
       continue;
@@ -154,8 +152,9 @@ const QList<int> & WebcamSource::getWebcamList()
     }
   }
 #elif defined(_IS_UNIX_)
-  int i = 0;
-  for (i = 0; i <= 10; ++i) {
+  const QString os = osName();
+  const bool skipOdd = (os == "Fedora" || os == "FreeBSD");
+  for (int i = 0; i <= 10; i += (1 + skipOdd)) {
     QFile file(QString("/dev/video%1").arg(i));
     if (file.open(QFile::ReadOnly)) {
       file.close();
@@ -240,6 +239,7 @@ bool WebcamSource::canOpenDeviceFile(int index)
   }
   return false;
 #else
+  Q_UNUSED(index)
   return true;
 #endif
 }
@@ -549,6 +549,9 @@ void WebcamSource::clearSavedSettings()
 
 QString WebcamSource::osName()
 {
+#ifdef _IS_FREEBSD_
+  return "FreeBSD";
+#else
   QFile file("/etc/os-release");
   if (!file.open(QIODevice::ReadOnly)) {
     qWarning("Warning: Cannot determine the os name (/etc/os-release file missing?)");
@@ -568,6 +571,7 @@ QString WebcamSource::osName()
     }
   }
   return "Unknown";
+#endif
 }
 
 bool WebcamSource::captureIsValid(const cv::VideoCapture & capture, int index)
